package com.endeavour.controller.form;

import java.io.IOException;
import java.sql.SQLException;
import java.util.Map;
import java.util.ResourceBundle;

import javax.faces.application.FacesMessage;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.validator.ValidatorException;

import com.endeavour.controller.VerificaCriacaoBD;
import com.endeavour.dao.UsuarioDAO;
import com.endeavour.model.Usuario;

public class LoginForm extends Object {
	private String email;
	private String senha;
	private ResourceBundle bundle;
	
	private FacesMessage loginAvisoDeErro;
	private FacesMessage emailAvisoDeErro;
	private FacesMessage senhaAvisoDeErro;
	private FacesMessage emailAvisoDeObrigatoriedade;
	private FacesMessage senhaAvisoDeObrigatoriedade;

	public String getSenha() {
		return senha;
	}

	public void setSenha(String string) {
		senha = string;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String string) {
		email = string;
	}

	public LoginForm() throws SQLException, IOException {
		VerificaCriacaoBD verificacao = new VerificaCriacaoBD();
		inicializarMensagens();
	}

	private void inicializarMensagens() {
		//Pega as mensagens de form/bundles/login.properties
		bundle = ResourceBundle.getBundle("form.bundles.login");
		String message = bundle.getString("tiltAvisoDeErro");
		loginAvisoDeErro = new FacesMessage(FacesMessage.SEVERITY_INFO,
				message, null);
		message = bundle.getString("emailAvisoDeErro");
		emailAvisoDeErro = new FacesMessage(FacesMessage.SEVERITY_INFO,
				message, null);
		message = bundle.getString("senhaAvisoDeErro");
		senhaAvisoDeErro = new FacesMessage(FacesMessage.SEVERITY_INFO,
				message, null);
		message = bundle.getString("emailAvisoDeObrigatoriedade");
		emailAvisoDeObrigatoriedade = new FacesMessage(FacesMessage.SEVERITY_INFO,
				message, null);
		message = bundle.getString("senhaAvisoDeObrigatoriedade");
		senhaAvisoDeObrigatoriedade = new FacesMessage(FacesMessage.SEVERITY_INFO,
				message, null);
	}

	public void validarEmail(FacesContext context, UIComponent toValidate,
			Object value) throws ValidatorException {
		int max = 100;
		
		String preenchido = (String) value;
		int length = preenchido.length();
		if (length > max) {
			throw new ValidatorException(emailAvisoDeErro);
		}
		return; 
	}

	public void validarSenha(FacesContext context, UIComponent toValidate,
			Object value) throws ValidatorException {
		int max = 30;
		
		String preenchido = (String) value;
		int length = preenchido.length();
		if (length > max) {
			throw new ValidatorException(senhaAvisoDeErro);
		}
		return; 
	}

	public String login() throws SQLException {
		UsuarioDAO usuarioDAO = new UsuarioDAO();
		Usuario usuario;
		FacesContext facesContext = FacesContext.getCurrentInstance();
		
		//verifica se os campos foram preenchidos
		boolean blnDeuErro = false;
		validarCamposObrigatorios();
		blnDeuErro = facesContext.getMessages().hasNext();
		
		
		
		if (!blnDeuErro) {
			//Verifica se temos o usuario no banco de dados e se sua senha confere
			try {
				usuario = usuarioDAO.getUsuario(this.getEmail());
			}
			catch (Exception e) {
				facesContext.addMessage(null, loginAvisoDeErro);
				return "erro";
			} 
			boolean blnOk = this.getSenha().equals(usuario.getSenha());	

			if(blnOk) {
				Map sessionMap = facesContext.getExternalContext().getSessionMap();
				sessionMap.put("email", getEmail());
				return "ok";
			}
			else {
				facesContext.addMessage(null, loginAvisoDeErro);
			}
			
		} else if (blnDeuErro == false)
			facesContext.addMessage(null, loginAvisoDeErro);
		return "erro";
	}

	protected boolean validarCamposObrigatorios() {
		boolean blnNaoPreencheu = false;
		FacesContext facesContext = FacesContext.getCurrentInstance();
		if (email != null && email.length() <= 0) {
			facesContext.addMessage(null, emailAvisoDeObrigatoriedade);
			blnNaoPreencheu = true;
		}
		if (senha != null && senha.length() <= 0) {
			facesContext.addMessage(null, senhaAvisoDeObrigatoriedade);
			blnNaoPreencheu = true;
		}
		
		return (!blnNaoPreencheu);
	}
}