DROP TABLE IF EXISTS Clans CASCADE;
CREATE TABLE Clans
(
codclan int not null identity primary key,
nome varchar(100) not null
);

DROP TABLE IF EXISTS Idiomas CASCADE;
CREATE TABLE Idiomas
(
codidioma int not null identity primary key,
nome varchar(70) not null,
locale varchar(5) null
);

DROP TABLE IF EXISTS Perfis CASCADE;
CREATE TABLE Perfis
(
codperfil int not null identity primary key,
nome varchar(100) not null
);

DROP TABLE IF EXISTS EstilosMusicais CASCADE;
CREATE TABLE EstilosMusicais
(
codestilomusical int not null identity primary key,
nome varchar(120) not null
);

DROP TABLE IF EXISTS Gravadoras CASCADE;
CREATE TABLE Gravadoras
(
codgravadora int not null identity primary key,
nome varchar(120) not null
);

DROP TABLE IF EXISTS Artistas CASCADE;
CREATE TABLE Artistas
(
codartista int not null identity primary key,
codgravadora int  not null,
nome varchar(140) not null,
foreign key (codgravadora) references Gravadoras(codgravadora)
);

DROP TABLE IF EXISTS Artistas_EstilosMusicais CASCADE;
CREATE TABLE Artistas_EstilosMusicais
(
codartista_estilomusical int not null identity primary key,
codartista int not null,
codestilomusical int not null,
foreign key (codartista) references Artistas(codartista),
foreign key (codestilomusical) references EstilosMusicais(codestilomusical)
);

DROP TABLE IF EXISTS Usuarios CASCADE;
CREATE TABLE Usuarios
(
codusuario int not null identity primary key,
nome varchar(50) not null,
sobrenome varchar(80) not null,
usuario varchar(30) not null,
senha varchar(30) not null,
email varchar(100) not null,
pontuacao int not null
);

DROP TABLE IF EXISTS Albuns CASCADE;
CREATE TABLE Albuns
(
codalbum int not null identity primary key,
codartista int not null,
nome varchar(120) not null,
capa varbinary null,
foreign key (codartista) references Artistas(codartista)
);

DROP TABLE IF EXISTS Musicas CASCADE;
CREATE TABLE Musicas
(
codmusica int not null identity primary key,
codidioma int not null,
codalbum int not null,
codusuario int not null,
titulo varchar(100) not null,
txtletra longvarchar not null,
ultimaAtualizacao datetime not null,
foreign key (codidioma) references Idiomas(codidioma),
foreign key (codalbum) references Albuns(codalbum),
foreign key (codusuario) references Usuarios(codusuario)
);

DROP TABLE IF EXISTS Usuarios_Perfis CASCADE;
CREATE TABLE Usuarios_Perfis
(
codusuario_perfil int not null identity primary key,
codusuario int not null,
codperfil int not null,
foreign key (codusuario) references Usuarios(codusuario),
foreign key (codperfil) references Perfis(codperfil)
);

DROP TABLE IF EXISTS Usuarios_Clans CASCADE;
CREATE TABLE Usuarios_Clans
(
codusuario_clan int not null identity primary key,
codusuario int not null,
codclan int not null,
foreign key (codusuario) references Usuarios(codusuario),
foreign key (codclan) references Clans(codclan)
); 

insert into EstilosMusicais (nome) values ('Rock progressivo');
insert into EstilosMusicais (nome) values ('POP');
insert into Gravadoras (nome) values ('Universal Music');
insert into Gravadoras (nome) values ('Inside Out');
insert into Idiomas (nome,locale) values ('Português (Brasil)','pt_br');
insert into Idiomas (nome,locale) values ('Inglês','en_us');
insert into Artistas (nome,codgravadora) values ('a-ha',0);
insert into Artistas (nome,codgravadora) values ('Dream theater',1);

insert into Albuns (nome,codartista) values ('Analogue (2005)',0);
insert into Albuns (nome,codartista) values ('Lifelines (2002)',0);
insert into Albuns (nome,codartista) values ('Minor Earth | Major Sky (2000)',0);
insert into Albuns (nome,codartista) values ('Memorial Beach (1993)',0);
insert into Albuns (nome,codartista) values ('East Of The Sun, West Of The Moon (1990)',0);
insert into Albuns (nome,codartista) values ('Stay On These Roads (1988)',0);
insert into Albuns (nome,codartista) values ('Scoundrel Days (1986)',0);
insert into Albuns (nome,codartista) values ('Hunting High and Low (1985)',0);
insert into Albuns (nome,codartista) values ('When Dream and day unite (1989)',1);
insert into Albuns (nome,codartista) values ('Images and Words (1992)',1);
insert into Albuns (nome,codartista) values ('Awake (1994)',1);
insert into Albuns (nome,codartista) values ('Falling into infinity (1997)',1);
insert into Albuns (nome,codartista) values ('Scenes from a memory (1999)',1);
insert into Albuns (nome,codartista) values ('Six degrees of inner turbulence (2002)',1);
insert into Albuns (nome,codartista) values ('Train of thought (2003)',1);
insert into Albuns (nome,codartista) values ('Octavarium (2005)',1);
insert into Albuns (nome,codartista) values ('Systematic Chaos (2007)',1);

insert into Usuarios (nome,sobrenome,email,usuario,senha,pontuacao) values ('Admin','do sistema','nilo.teixeira@gmail.com','admin','teste',0);
insert into Usuarios (nome,sobrenome,email,usuario,senha,pontuacao) values ('Usuario','do sistema','nilo.teixeira@gmail.com','user','teste',0);
insert into Usuarios (nome,sobrenome,email,usuario,senha,pontuacao) values ('teste','do sistema','teste','teste','teste',0);

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Celice','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Don''t Do Me Any Favours','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Cosy Prisons','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Analogue (All I Want)','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Birthright','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Holyground','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Over The Treetops','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Halfway Through The Tour','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'A Fine Blue Line','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Keeper Of The Flame','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'Make It Soon','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'White Dwarf','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,0,1,'The Summers Of Our Youth','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Lifelines','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'You Wanted More','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Forever Not Yours','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'There''s a Reason for It','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Time & Again','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Did Anyone Approach You?','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Afternoon High','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Oranges on Appletrees','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'A Little Bit','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Less Than Pure','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Turn the Lights Down','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Cannot Hide','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'White Canvas','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Dragonfly','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,1,1,'Solace','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Minor Earth Major Sky','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Little Black Heart','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Velvet','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Summer Moved On','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'The Sun Never Shone That Day','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'To Let You Win','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'The Company Man','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Thought That It Was You','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'I Wish I Cared','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Barely Hanging On','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'You''ll Never Get Over Me ','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'I Won''t Forget Her','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,2,1,'Mary Ellen Makes the Moment Count','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Dark Is the Night for All','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Move to Memphis','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Cold as Stone','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Angel in the Snow','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Locust','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Lie Down in Darkness','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'How Sweet It Was','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Lamb to the Slaughter','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Between Your Mama and Yourself','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,3,1,'Memorial Beach','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Crying in the Rain','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Early Morning','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'I Call Your Name','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Slender Frame','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'East of the Sun West of the Moon','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Sycamore Leaves','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Waiting for Her','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Cold River','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'The Way We Talk','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'Rolling Thunder','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,4,1,'(Seemingly) Nonstop July','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'Stay on These Roads','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'The Blood That Moves the Body','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'Touchy!','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'This Alone Is Love','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'Hurry Home','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'The Living Daylights','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'There''s Never a Forever Thing','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'Out of Blue Comes Green','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'You Are the One','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,5,1,'You''ll End up Crying','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'Scoundrel Days','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'The Swing of Things','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'I''ve Been Losing You','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'October','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'Manhattan Skyline','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'Cry Wolf','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'We''re Looking for the Whales','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'The Weight of the Wind','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'Maybe, Maybe','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,6,1,'Soft Rains of April','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Take on Me','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Train of Thought','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Hunting High and Low','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'The Blue Sky','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Living a Boy''s Adventure Tale','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'The Sun Always Shines on T.V.','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'And You Tell Me','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Love Is Reason','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'I Dream Myself Alive','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,7,1,'Here I Stand and Face the Rain','[Editar letra...]',NOW());


insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'A Fortune In Lies','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'Status Seeker','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'The Ytse Jam','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'The Killing Hand','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'Light Fuse And Get Away','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'After Life','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'The Ones Who Help To Set The Sun','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,8,1,'Only A Matter Of Time','[Editar letra...]',NOW());


insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Pull Me Under','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Another Day','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Take The Time','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Surrounded','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Metropolis - Part I "The Miracle And The Sleeper"','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Under A Glass Moon','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Wait For Sleep','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,9,1,'Learning To Live','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'6:00','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Caught In A Web','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Innocence Faded','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Erotomania (instrumental)','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Voices','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'The Silent Man','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'The Mirror','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Lie','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Lifting Shadows Off A Dream','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Scarred','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,10,1,'Space-Dye Vest','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'New Millennium','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'You Not Me','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Peruvian Skies','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Hollow Years','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Burning My Soul','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Hell''s Kitchen','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Lines In The Sand','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Take Away My Pain','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Just Let Me Breathe','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Anna Lee','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,11,1,'Trial Of Tears ','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Regression','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Overture 1928','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Strange Deja Vu','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Through My Words','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Fatal Tragedy','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Beyond This Life','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Through Her Eyes','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Home','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'The Dance of Eternity','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'One Last Time','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'The Spirit Carries On','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,12,1,'Finally Free','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'The Glass Prison','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'Blind Faith','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'Misunderstood','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'The Great Debate','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'Disappear','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) Overture','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) About to Crash','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) War Inside My Head','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) The Test That Stumped Them All','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) Goodnight Kiss','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) Solitary Shell','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) About to Crash (Reprise)','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,13,1,'(SDoIT) Losing Time/Grand Finale','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'As I Am','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'This Dying Soul','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'Endless Sacrifice','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'Honor Thy Father','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'Vacant','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'Stream Of Consciousness','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,14,1,'In The Name Of God','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'The Root Of All Evil','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'The Answer Lies Within','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'These Walls','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'I Walk Beside You','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'Panic Attack','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'Never Enough','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'Sacrificed Sons','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,15,1,'Octavarium','[Editar letra...]',NOW());

insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'In The Presence of Enemies Pt.1','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'Forsaken','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'Constant Motion','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'The Dark Eternal Night','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'Repentance','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'Prophets Of War','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'The Ministry of Lost Souls','[Editar letra...]',NOW());
insert into Musicas
(codidioma,codalbum,codusuario,titulo,txtletra,ultimaAtualizacao)
values
(1,16,1,'In The Presence of Enemies Pt.2','[Editar letra...]',NOW());
